/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.applicationautoscaling.model;

import java.io.Serializable;

/**
 * 
 */
public class DescribeScalingPoliciesResult implements Serializable, Cloneable {

    /**
     * <p>
     * A list of scaling policy objects.
     * </p>
     */
    private java.util.List<ScalingPolicy> scalingPolicies;
    /**
     * <p>
     * The <code>NextToken</code> value to include in a future
     * <code>DescribeScalingPolicies</code> request. When the results of a
     * <code>DescribeScalingPolicies</code> request exceed
     * <code>MaxResults</code>, this value can be used to retrieve the next page
     * of results. This value is <code>null</code> when there are no more
     * results to return.
     * </p>
     */
    private String nextToken;

    /**
     * <p>
     * A list of scaling policy objects.
     * </p>
     * 
     * @return A list of scaling policy objects.
     */

    public java.util.List<ScalingPolicy> getScalingPolicies() {
        return scalingPolicies;
    }

    /**
     * <p>
     * A list of scaling policy objects.
     * </p>
     * 
     * @param scalingPolicies
     *        A list of scaling policy objects.
     */

    public void setScalingPolicies(
            java.util.Collection<ScalingPolicy> scalingPolicies) {
        if (scalingPolicies == null) {
            this.scalingPolicies = null;
            return;
        }

        this.scalingPolicies = new java.util.ArrayList<ScalingPolicy>(
                scalingPolicies);
    }

    /**
     * <p>
     * A list of scaling policy objects.
     * </p>
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setScalingPolicies(java.util.Collection)} or
     * {@link #withScalingPolicies(java.util.Collection)} if you want to
     * override the existing values.
     * </p>
     * 
     * @param scalingPolicies
     *        A list of scaling policy objects.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public DescribeScalingPoliciesResult withScalingPolicies(
            ScalingPolicy... scalingPolicies) {
        if (this.scalingPolicies == null) {
            setScalingPolicies(new java.util.ArrayList<ScalingPolicy>(
                    scalingPolicies.length));
        }
        for (ScalingPolicy ele : scalingPolicies) {
            this.scalingPolicies.add(ele);
        }
        return this;
    }

    /**
     * <p>
     * A list of scaling policy objects.
     * </p>
     * 
     * @param scalingPolicies
     *        A list of scaling policy objects.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public DescribeScalingPoliciesResult withScalingPolicies(
            java.util.Collection<ScalingPolicy> scalingPolicies) {
        setScalingPolicies(scalingPolicies);
        return this;
    }

    /**
     * <p>
     * The <code>NextToken</code> value to include in a future
     * <code>DescribeScalingPolicies</code> request. When the results of a
     * <code>DescribeScalingPolicies</code> request exceed
     * <code>MaxResults</code>, this value can be used to retrieve the next page
     * of results. This value is <code>null</code> when there are no more
     * results to return.
     * </p>
     * 
     * @param nextToken
     *        The <code>NextToken</code> value to include in a future
     *        <code>DescribeScalingPolicies</code> request. When the results of
     *        a <code>DescribeScalingPolicies</code> request exceed
     *        <code>MaxResults</code>, this value can be used to retrieve the
     *        next page of results. This value is <code>null</code> when there
     *        are no more results to return.
     */

    public void setNextToken(String nextToken) {
        this.nextToken = nextToken;
    }

    /**
     * <p>
     * The <code>NextToken</code> value to include in a future
     * <code>DescribeScalingPolicies</code> request. When the results of a
     * <code>DescribeScalingPolicies</code> request exceed
     * <code>MaxResults</code>, this value can be used to retrieve the next page
     * of results. This value is <code>null</code> when there are no more
     * results to return.
     * </p>
     * 
     * @return The <code>NextToken</code> value to include in a future
     *         <code>DescribeScalingPolicies</code> request. When the results of
     *         a <code>DescribeScalingPolicies</code> request exceed
     *         <code>MaxResults</code>, this value can be used to retrieve the
     *         next page of results. This value is <code>null</code> when there
     *         are no more results to return.
     */

    public String getNextToken() {
        return this.nextToken;
    }

    /**
     * <p>
     * The <code>NextToken</code> value to include in a future
     * <code>DescribeScalingPolicies</code> request. When the results of a
     * <code>DescribeScalingPolicies</code> request exceed
     * <code>MaxResults</code>, this value can be used to retrieve the next page
     * of results. This value is <code>null</code> when there are no more
     * results to return.
     * </p>
     * 
     * @param nextToken
     *        The <code>NextToken</code> value to include in a future
     *        <code>DescribeScalingPolicies</code> request. When the results of
     *        a <code>DescribeScalingPolicies</code> request exceed
     *        <code>MaxResults</code>, this value can be used to retrieve the
     *        next page of results. This value is <code>null</code> when there
     *        are no more results to return.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public DescribeScalingPoliciesResult withNextToken(String nextToken) {
        setNextToken(nextToken);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getScalingPolicies() != null)
            sb.append("ScalingPolicies: " + getScalingPolicies() + ",");
        if (getNextToken() != null)
            sb.append("NextToken: " + getNextToken());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof DescribeScalingPoliciesResult == false)
            return false;
        DescribeScalingPoliciesResult other = (DescribeScalingPoliciesResult) obj;
        if (other.getScalingPolicies() == null
                ^ this.getScalingPolicies() == null)
            return false;
        if (other.getScalingPolicies() != null
                && other.getScalingPolicies().equals(this.getScalingPolicies()) == false)
            return false;
        if (other.getNextToken() == null ^ this.getNextToken() == null)
            return false;
        if (other.getNextToken() != null
                && other.getNextToken().equals(this.getNextToken()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getScalingPolicies() == null) ? 0 : getScalingPolicies()
                        .hashCode());
        hashCode = prime * hashCode
                + ((getNextToken() == null) ? 0 : getNextToken().hashCode());
        return hashCode;
    }

    @Override
    public DescribeScalingPoliciesResult clone() {
        try {
            return (DescribeScalingPoliciesResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
